@@ -50,7 +50,7 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
     async def test_box_inplace(self):
         with open('data/source/x.csv', 'rb') as f:
             original_content = f.read()
-        await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': '*.csv'}))
+        await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': '*.csv', '7za': '-tzip'}))
         with ZipFile('data/source/x.csv.zip') as zf:
             with zf.open('x.csv') as f:
                 self.assertEqual(original_content, f.read(), 'zipped content is identical')
@@ -61,7 +61,7 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
         chdir('data/source')
         with open('x.csv', 'rb') as f:
             original_content = f.read()
-        await box(Config(CLI_DEFAULTS | {'glob': '*.csv'}))
+        await box(Config(CLI_DEFAULTS | {'glob': '*.csv', '7za': '-tzip'}))
         with ZipFile('x.csv.zip') as zf:
             with zf.open('x.csv') as f:
                 self.assertEqual(original_content, f.read(), 'zipped content is identical')
@@ -74,7 +74,7 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
 
     async def test_box_create_folders(self):
         await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'target': 'data/target', 'glob': '**/*.csv',
-                                         'delete': False}))
+                                         'delete': False, '7za': '-tzip'}))
         with ZipFile('data/target/x.csv.zip') as zf:
             with zf.open('x.csv') as fz:
                 with open('data/source/x.csv', 'rb') as f:
@@ -87,7 +87,8 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
 
     async def test_box_zip_structure(self):
         await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'target': 'data/target', 'glob': '**/*.csv',
-                                         'delete': False, 'create_folders': False, 'zip_structure': True}))
+                                         'delete': False, 'create_folders': False, 'zip_structure': True,
+                                         '7za': '-tzip'}))
         with ZipFile('data/target/x.csv.zip') as zf:
             with zf.open('x.csv') as fz:
                 with open('data/source/x.csv', 'rb') as f:
@@ -98,52 +99,61 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
                 with open('data/source/sub/y.csv', 'rb') as f:
                     self.assertEqual(f.read(), fz.read(), 'zipped content in sub-folder is identical')
 
-    async def test_box_round_trip(self):
-        await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': '*.csv'}))
+    async def test_box_round_trip_zip(self):
+        await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': '*.csv', '7za': '-tzip'}))
         self.assertFalse(Path('data/source/x.csv').is_file(), 'original is gone after box')
         self.assertTrue(Path('data/source/x.csv.zip').is_file(), 'archive exists after box')
         await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': '*.csv.zip', 'unbox': True}))
         self.assertTrue(Path('data/source/x.csv').is_file(), 'original is back after unbox')
         self.assertFalse(Path('data/source/x.csv.zip').is_file(), 'archive removed after unbox')
 
+    async def test_box_round_trip_7z(self):
+        await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': '*.csv'}))
+        self.assertFalse(Path('data/source/x.csv').is_file(), 'original is gone after box')
+        self.assertTrue(Path('data/source/x.csv.7z').is_file(), 'archive exists after box')
+        await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': '*.csv.7z', 'unbox': True}))
+        self.assertTrue(Path('data/source/x.csv').is_file(), 'original is back after unbox')
+        self.assertFalse(Path('data/source/x.csv.7z').is_file(), 'archive removed after unbox')
+
     async def test_box_overwrite_zip(self):
-        await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': 'x.csv', 'delete': False}))
+        await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': 'x.csv', 'delete': False, '7za': '-tzip'}))
         self.assertTrue(Path('data/source/x.csv.zip').is_file(), 'archive exists after first box')
         await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': 'x.csv'}))
         self.assertFalse(Path('data/source/x.csv').is_file(), 'original is gone after box')
         with ZipFile('data/source/x.csv.zip') as zf:
             self.assertEqual(1, len(zf.filelist), 'Only one file in resulting archive')
 
-    async def _do_test_overwrite(self, mode=None):
+    async def _do_test_overwrite(self, mode=None, suffix='zip'):
         with open('data/source/x.csv') as f:
             content = f.read()
-        await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': 'x.csv', 'delete': False}))
+        await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': 'x.csv', 'delete': False,
+                                         '7za': f'-t{suffix}'}))
         with open('data/source/x.csv', 'a') as f:
             f.write('extra')
             new_content = content + 'extra'
         if mode is None:
-            await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': 'x.csv.zip', 'unbox': True}))
+            await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': f'x.csv.{suffix}', 'unbox': True}))
         else:
-            await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': 'x.csv.zip', 'unbox': True,
+            await box(Config(CLI_DEFAULTS | {'root': 'data/source', 'glob': f'x.csv.{suffix}', 'unbox': True,
                                              'overwrite': mode}))
         return content, new_content
 
     async def test_box_overwrite_source_skip_default(self):
-        content, new_content = await self._do_test_overwrite()
+        content, new_content = await self._do_test_overwrite(suffix='zip')
         self.assertFalse(Path('data/source/x.csv.zip').is_file(), 'archive is gone after unbox')
         self.assertTrue(Path('data/source/x.csv').is_file(), '"original" file exist')
         with open('data/source/x.csv') as f:
             self.assertEqual(new_content, f.read(), 'Content of original file untouched, no overwrite')
 
     async def test_box_overwrite_source_all(self):
-        content, new_content = await self._do_test_overwrite('a')
+        content, new_content = await self._do_test_overwrite('a', suffix='zip')
         self.assertFalse(Path('data/source/x.csv.zip').is_file(), 'archive is gone after unbox')
         self.assertTrue(Path('data/source/x.csv').is_file(), '"original" file exist')
         with open('data/source/x.csv') as f:
             self.assertEqual(content, f.read(), 'Content of original file back to original, overwritten')
 
-    async def test_box_overwrite_source_rename_new(self):
-        content, new_content = await self._do_test_overwrite('u')
+    async def test_box_overwrite_source_rename_new_zip(self):
+        content, new_content = await self._do_test_overwrite('u', suffix='zip')
         self.assertFalse(Path('data/source/x.csv.zip').is_file(), 'archive is gone after unbox')
         self.assertTrue(Path('data/source/x.csv').is_file(), '"original" file exist')
         with open('data/source/x.csv') as f:
@@ -152,8 +162,28 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
         with open('data/source/x_1.csv') as f:
             self.assertEqual(content, f.read(), 'Extracted file contains original content')
 
-    async def test_box_overwrite_source_rename_existing(self):
-        content, new_content = await self._do_test_overwrite('t')
+    async def test_box_overwrite_source_rename_new_7z(self):
+        content, new_content = await self._do_test_overwrite('u', suffix='7z')
+        self.assertFalse(Path('data/source/x.csv.zip').is_file(), 'archive is gone after unbox')
+        self.assertTrue(Path('data/source/x.csv').is_file(), '"original" file exist')
+        with open('data/source/x.csv') as f:
+            self.assertEqual(new_content, f.read(), 'Content of original file untouched, no overwrite')
+        self.assertTrue(Path('data/source/x_1.csv').is_file(), 'extracted file was renamed')
+        with open('data/source/x_1.csv') as f:
+            self.assertEqual(content, f.read(), 'Extracted file contains original content')
+
+    async def test_box_overwrite_source_rename_existing_zip(self):
+        content, new_content = await self._do_test_overwrite('t', suffix='zip')
+        self.assertFalse(Path('data/source/x.csv.zip').is_file(), 'archive is gone after unbox')
+        self.assertTrue(Path('data/source/x.csv').is_file(), '"original" file exist')
+        with open('data/source/x.csv') as f:
+            self.assertEqual(content, f.read(), 'extracted file to original name, original content')
+        self.assertTrue(Path('data/source/x_1.csv').is_file(), 'existing file was renamed')
+        with open('data/source/x_1.csv') as f:
+            self.assertEqual(new_content, f.read(), 'Existing files still contains new content')
+
+    async def test_box_overwrite_source_rename_existing_7z(self):
+        content, new_content = await self._do_test_overwrite('t', suffix='7z')
         self.assertFalse(Path('data/source/x.csv.zip').is_file(), 'archive is gone after unbox')
         self.assertTrue(Path('data/source/x.csv').is_file(), '"original" file exist')
         with open('data/source/x.csv') as f:
@@ -163,17 +193,17 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
             self.assertEqual(new_content, f.read(), 'Existing files still contains new content')
 
     async def test_box_dir_default(self):
-        await box(Config(CLI_DEFAULTS | {'glob': '**/*.csv'}))
+        await box(Config(CLI_DEFAULTS | {'glob': '**/*.csv', '7za': '-tzip'}))
         self.assertTrue(Path('data/source/x.csv.zip').is_file(), 'archive in-place default')
         self.assertTrue(Path('data/source/sub/y.csv.zip').is_file(), 'archive subs in-place default')
 
     async def test_box_dir_root(self):
-        await box(Config(CLI_DEFAULTS | {'root': 'data/source/sub', 'glob': '**/*.csv'}))
+        await box(Config(CLI_DEFAULTS | {'root': 'data/source/sub', 'glob': '**/*.csv', '7za': '-tzip'}))
         self.assertFalse(Path('data/source/x.csv.zip').is_file(), 'no archive in root parent')
         self.assertTrue(Path('data/source/sub/y.csv.zip').is_file(), 'archive subs in-place from root')
 
     async def test_box_dir_target(self):
-        await box(Config(CLI_DEFAULTS | {'glob': '**/*.csv', 'target': 'data/target'}))
+        await box(Config(CLI_DEFAULTS | {'glob': '**/*.csv', 'target': 'data/target', '7za': '-tzip'}))
         self.assertTrue(Path('data/target/data/source/x.csv.zip').is_file(),
                         'archive in target, relative to working')
         self.assertTrue(Path('data/target/data/source/sub/y.csv.zip').is_file(),
@@ -182,7 +212,8 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
                         'archive sub-subs in target, relative to working')
 
     async def test_box_dir_target_root(self):
-        await box(Config(CLI_DEFAULTS | {'glob': '**/*.csv', 'target': 'data/target', 'root': 'data/source'}))
+        await box(Config(CLI_DEFAULTS | {'glob': '**/*.csv', 'target': 'data/target', 'root': 'data/source',
+                                         '7za': '-tzip'}))
         self.assertTrue(Path('data/target/x.csv.zip').is_file(),
                         'archive in target, relative to root')
         self.assertTrue(Path('data/target/sub/y.csv.zip').is_file(),
@@ -191,12 +222,12 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
                         'archive sub-subs in target, relative to root')
 
     async def test_box_dirs_no_match(self):
-        await box(Config(CLI_DEFAULTS | {'glob': 'sub?', 'root': 'data/source'}))
+        await box(Config(CLI_DEFAULTS | {'glob': 'sub?', 'root': 'data/source', '7za': '-tzip'}))
         self.assertFalse(Path('data/source/sub2.zip').is_file(),
                         'no zipped subdirectory without --match_dir')
 
     async def test_box_dirs_match(self):
-        await box(Config(CLI_DEFAULTS | {'glob': 'sub?', 'root': 'data/source', 'match_dir': True}))
+        await box(Config(CLI_DEFAULTS | {'glob': 'sub?', 'root': 'data/source', 'match_dir': True, '7za': '-tzip'}))
         self.assertTrue(Path('data/source/sub2.zip').is_file(),
                         'zipped subdirectory in-place')
         self.assertFalse(Path('data/source/sub2').is_dir(),
@@ -217,7 +248,7 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
     async def test_box_dirs_subdirs(self):
         with open('data/source/sub/subsub/z.csv', 'rb') as f:
             content = f.read()
-        await box(Config(CLI_DEFAULTS | {'glob': 'sub', 'root': 'data/source', 'match_dir': True}))
+        await box(Config(CLI_DEFAULTS | {'glob': 'sub', 'root': 'data/source', 'match_dir': True, '7za': '-tzip'}))
         self.assertTrue(Path('data/source/sub.zip').is_file(),
                         'archive exists')
         with ZipFile('data/source/sub.zip') as zf:
@@ -225,13 +256,13 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
                 self.assertEqual(content, f.read(), 'zipped content contains files in subdirs')
 
     async def test_box_dirs_match_files(self):
-        await box(Config(CLI_DEFAULTS | {'glob': '**/sub?', 'match_dir': True, 'match_file': True}))
+        await box(Config(CLI_DEFAULTS | {'glob': '**/sub?', 'match_dir': True, 'match_file': True, '7za': '-tzip'}))
         self.assertTrue(Path('data/source/sub3.zip').is_file(),
                         'zipped subdirectories in-place')
         self.assertTrue(Path('data/source/sub4.zip').is_file(),
                         'zipped files in-place')
         await box(Config(CLI_DEFAULTS | {'glob': 'sub?.zip', 'root': 'data/source', 'unbox': True,
-                                         'unbox_multi': True}))
+                                         'unbox_multi': True, '7za': '-tzip'}))
         self.assertTrue(Path('data/source/sub3').is_dir(),
                        'zipped subdirectory restored')
         self.assertTrue(Path('data/source/sub3/y3.csv').is_file(),
@@ -239,44 +270,44 @@ class TestPy7zaBox(unittest.IsolatedAsyncioTestCase):
         self.assertTrue(Path('data/source/sub4').is_file(),
                        'zipped files restored')
         self.setUp()
-        await box(Config(CLI_DEFAULTS | {'glob': '**/sub?', 'match_dir': True, 'match_file': False}))
+        await box(Config(CLI_DEFAULTS | {'glob': '**/sub?', 'match_dir': True, 'match_file': False, '7za': '-tzip'}))
         self.assertTrue(Path('data/source/sub3.zip').is_file(),
                         'zipped subdirectories in-place')
         self.assertFalse(Path('data/source/sub4.zip').is_file(),
                          'no files matched and zipped')
 
     async def test_box_multi_glob(self):
-        await box(Config(CLI_DEFAULTS) | {'glob': ['**/*.csv', '**/*.txt'], 'root': 'data'})
+        await box(Config(CLI_DEFAULTS) | {'glob': ['**/*.csv', '**/*.txt'], 'root': 'data', '7za': '-tzip'})
         self.assertTrue(Path('data/source/sub/test.txt.zip').is_file(),
                        'txt files matched in multi-glob')
         self.assertTrue(Path('data/source/sub/y.csv.zip').is_file(),
                        'csv files matched in multi-glob')
 
     async def test_zip_archives(self):
-        await box(Config(CLI_DEFAULTS) | {'glob': '**/*', 'root': 'data'})
+        await box(Config(CLI_DEFAULTS) | {'glob': '**/*', 'root': 'data', '7za': '-tzip'})
         self.assertTrue(Path('data/source/sub/test.txt.zip').is_file(),
                        'txt files matched in catch all')
         self.assertTrue(Path('data/source/sub/y.csv.zip').is_file(),
                        'csv files matched in catch all')
         with open('data/source/new.txt', 'w') as f:
             f.write('test')
-        await box(Config(CLI_DEFAULTS) | {'glob': '**/*', 'root': 'data'})
+        await box(Config(CLI_DEFAULTS) | {'glob': '**/*', 'root': 'data', '7za': '-tzip'})
         self.assertTrue(Path('data/source/new.txt.zip').is_file(),
                        'new txt files matched in catch all')
-        await box(Config(CLI_DEFAULTS) | {'glob': '**/*.zip', 'unbox': True, 'root': 'data'})
+        await box(Config(CLI_DEFAULTS) | {'glob': '**/*.zip', 'unbox': True, 'root': 'data', '7za': '-tzip'})
         self.assertFalse(Path('data/source/sub/test.txt.zip').is_file(),
                          'zip files were not rezipped and')
         self.assertTrue(Path('data/source/sub/test.txt').is_file(),
                        'original content from previously created archive extracted')
 
     async def test_unbox_multi(self):
-        await box(Config(CLI_DEFAULTS | {'glob': '**/sub', 'match_dir': True}))
+        await box(Config(CLI_DEFAULTS | {'glob': '**/sub', 'match_dir': True, '7za': '-tzip'}))
         self.assertTrue(Path('data/source/sub.zip').is_file(),
                         'zipped files in sub in single archive')
-        await box(Config(CLI_DEFAULTS | {'glob': '**/*.zip', 'unbox': True}))
+        await box(Config(CLI_DEFAULTS | {'glob': '**/*.zip', 'unbox': True, '7za': '-tzip'}))
         self.assertTrue(Path('data/source/sub.zip').is_file(),
                         'default unbox_multi False, archive not extracted')
-        await box(Config(CLI_DEFAULTS | {'glob': '**/*.zip', 'unbox': True, 'unbox_multi': True}))
+        await box(Config(CLI_DEFAULTS | {'glob': '**/*.zip', 'unbox': True, 'unbox_multi': True, '7za': '-tzip'}))
         self.assertTrue(Path('data/source/sub/y.csv').is_file() and Path('data/source/sub/test.txt').is_file(),
                         'unbox_multi True, files extracted')
         self.assertFalse(Path('data/source/sub.zip').is_file(),
